from PySide6 import QtWidgets
import sys
from maol.wid import MyWidget


if __name__ == "__main__":
    app = QtWidgets.QApplication([])

    widget = MyWidget()
    widget.resize(800, 600)
    widget.show()

    sys.exit(app.exec())


from setuptools import find_packages, setup




setup(
    name="maol",
    version="0.0.0.1",
    description="Model Assisted Object Labeling Toolkit",
    long_description_content_type="text/markdown",
    author="Matthew Sessions",
    packages=find_packages(exclude=["tests", ".github"]),
    install_requires=["PySide6"],

)
